@@ -397,7 +397,7 @@ bool X11Locker::nativeEventFilter(const QByteArray &eventType, void *message, lo
                     m_windowInfo[ index ].viewable = false;
                 else
                     qDebug() << "Unknown toplevel for MapNotify";
-                m_lockWindows.removeAll(xu->event);
+                m_lockWindows.removeAll(xu->window);
                 if (m_focusedLockWindow == xu->event && !m_lockWindows.empty()) {
                     // The currently focused window vanished, just focus the first one in the list
                     fakeFocusIn(m_lockWindows[0]);
